#!/bin/sh
# Copyright start
# Copyright (C) 2008 - 2023 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end

init() {
    #
    # Below file is created as last step of
    # /opt/cyops/scripts/cloud/openstack/initialize_forticloud_config.py
    #
    FLAGS_DIR="/opt/cyops/configs/.flags"
    FILE_FSR_INIT_CONFIG_COMPLETED="$FLAGS_DIR/.forticloud-init-config-completed"
    FILE_CONFIG_VM_COMPLETED="$FLAGS_DIR/.vm_configured"
    FILE_FSR_INIT_CONFIG_RESTRICT_RERUN="$FLAGS_DIR/.restrict-rerun-for-forticloud-init-config"
}

is_first_boot() {
    if [ -f "$FILE_FSR_INIT_CONFIG_COMPLETED" ] || [ -f "$FILE_CONFIG_VM_COMPLETED" ]; then
        # 1 means False
        return 1
    fi
    # 0 means True
    return 0
}

handle_first_boot() {
    echo "Starting config VM"
    /opt/cyops/scripts/config-vm.sh --non-interactive
    echo "Starting enable embedded SME"
    csadm secure-message-exchange enable --no-interaction
    # Remove secure message exchange management API port in firewall
    csadm secure-message-exchange management-extension block-port
}

#############
#Main/main/MAIN starts here
##############

init

# Exit in case of any failure
set -e

monitor_parameters=""

if is_first_boot; then
    echo "Running first boot"
    handle_first_boot
fi

monitor_parameters=""

if [ -f "$FILE_FSR_INIT_CONFIG_COMPLETED" ]; then
    # This is subsequent boot
    # This is subsequent boot. Delete the flag to run init config script again with parameter --subsequent-boot
    echo "Running subsequent boot"
    echo "Removing file [$FILE_FSR_INIT_CONFIG_RESTRICT_RERUN]"
    rm -f $FILE_FSR_INIT_CONFIG_RESTRICT_RERUN
    monitor_parameters="--subsequent-boot"
fi

script_monitor_forticloud_init_config="/opt/cyops/scripts/cloud/openstack/monitor-forticloud-init-config.sh $monitor_parameters"

echo "Running script [$script_monitor_forticloud_init_config]"

sh $script_monitor_forticloud_init_config &

cron_file=/etc/cron.d/monitor-forticloud-init-config

echo "Setting cron [$cron_file]"

echo "*/1 * * * * root sh $script_monitor_forticloud_init_config" > $cron_file
